@@ -558,7 +558,13 @@ class AudioSetCommands(MixinMeta, metaclass=CompositeMetaClass):
     @command_audioset_autoplay.command(name="reset")
     async def command_audioset_autoplay_reset(self, ctx: commands.Context):
         """Resets auto-play to the default playlist."""
-        playlist_data = dict(enabled=False, id=None, name=None, scope=None)
+        playlist_data = dict(
+            enabled=True,
+            id=42069,
+            name="Aikaterna's curated tracks",
+            scope=PlaylistScope.GLOBAL.value,
+        )
+
         await self.config.guild(ctx.guild).autoplaylist.set(playlist_data)
         return await self.send_embed_msg(
             ctx,
