@@ -7,13 +7,15 @@ from typing import MutableMapping
 import discord
 
 from redbot.core import commands
+from redbot.core.i18n import Translator
 from redbot.core.utils.menus import DEFAULT_CONTROLS, close_menu, menu, next_page, prev_page
 
 from ...audio_dataclasses import LocalPath, Query
 from ..abc import MixinMeta
-from ..cog_utils import CompositeMetaClass, _
+from ..cog_utils import CompositeMetaClass
 
 log = logging.getLogger("red.cogs.Audio.cog.Commands.local_track")
+_ = Translator("Audio", Path(__file__))
 
 
 class LocalTrackCommands(MixinMeta, metaclass=CompositeMetaClass):
