@@ -4,14 +4,17 @@ import datetime
 import json
 import logging
 import math
+import random
+import time
 from pathlib import Path
 
 from typing import List, MutableMapping, Optional, Tuple, Union
 
+import aiohttp
 import discord
 import lavalink
-
 from discord.embeds import EmptyEmbed
+
 from redbot.core import commands
 from redbot.core.i18n import Translator
 from redbot.core.utils import AsyncIter
@@ -19,7 +22,7 @@ from redbot.core.utils.chat_formatting import box
 from redbot.core.utils.menus import start_adding_reactions
 from redbot.core.utils.predicates import ReactionPredicate
 
-from ...apis.playlist_interface import Playlist, create_playlist
+from ...apis.playlist_interface import Playlist, PlaylistCompat23, create_playlist
 from ...audio_dataclasses import _PARTIALLY_SUPPORTED_MUSIC_EXT, Query
 from ...audio_logging import debug_exc_log
 from ...errors import TooManyMatches, TrackEnqueueError
@@ -29,6 +32,9 @@ from ..cog_utils import CompositeMetaClass
 
 log = logging.getLogger("red.cogs.Audio.cog.Utilities.playlists")
 _ = Translator("Audio", Path(__file__))
+CURRATED_DATA = (
+    "https://gist.githubusercontent.com/Drapersniper/cbe10d7053c844f8c69637bb4fd9c5c3/raw/json"
+)
 
 
 class PlaylistUtilities(MixinMeta, metaclass=CompositeMetaClass):
@@ -470,6 +476,18 @@ class PlaylistUtilities(MixinMeta, metaclass=CompositeMetaClass):
     async def _maybe_update_playlist(
         self, ctx: commands.Context, player: lavalink.player_manager.Player, playlist: Playlist
     ) -> Tuple[List[lavalink.Track], List[lavalink.Track], Playlist]:
+        if playlist.id == 42069:
+            _, updated_tracks = await self._get_bundled_playlist_tracks()
+            results = {}
+            old_tracks = playlist.tracks_obj
+            new_tracks = [lavalink.Track(data=track) for track in updated_tracks]
+            removed = list(set(old_tracks) - set(new_tracks))
+            added = list(set(new_tracks) - set(old_tracks))
+            if removed or added:
+                await playlist.edit(results)
+
+            return added, removed, playlist
+
         if playlist.url is None:
             return [], [], playlist
         results = {}
@@ -517,10 +535,14 @@ class PlaylistUtilities(MixinMeta, metaclass=CompositeMetaClass):
                         description=_("I don't have permission to connect to your channel."),
                     )
                     return False
-                await lavalink.connect(ctx.author.voice.channel)
+                await lavalink.connect(
+                    ctx.author.voice.channel,
+                    deafen=await self.config.guild_from_id(ctx.guild.id).auto_deafen(),
+                )
                 player = lavalink.get_player(ctx.guild.id)
                 player.store("connect", datetime.datetime.utcnow())
-                await self.self_deafen(player)
+                player.store("channel", ctx.channel.id)
+                player.store("guild", ctx.guild.id)
             except IndexError:
                 await self.send_embed_msg(
                     ctx,
@@ -564,7 +586,7 @@ class PlaylistUtilities(MixinMeta, metaclass=CompositeMetaClass):
 
         if query.is_spotify:
             try:
-                if self.play_lock[ctx.message.guild.id]:
+                if self.play_lock[ctx.guild.id]:
                     return await self.send_embed_msg(
                         ctx,
                         title=_("Unable To Get Tracks"),
@@ -659,3 +681,50 @@ class PlaylistUtilities(MixinMeta, metaclass=CompositeMetaClass):
             return ctx.name if ctx else _("the Server") if the else _("Server")
         elif scope == PlaylistScope.USER.value:
             return str(ctx) if ctx else _("the User") if the else _("User")
+
+    async def _get_bundled_playlist_tracks(self):
+        async with aiohttp.ClientSession(json_serialize=json.dumps) as session:
+            async with session.get(
+                CURRATED_DATA + f"?timestamp={int(time.time())}",
+                headers={"content-type": "application/json"},
+            ) as response:
+                if response.status != 200:
+                    return 0, []
+                try:
+                    data = json.loads(await response.read())
+                except Exception:
+                    log.exception("Curated playlist couldn't be parsed, report this error.")
+                    data = {}
+                web_version = data.get("version", 0)
+                entries = data.get("entries", [])
+                if entries:
+                    random.shuffle(entries)
+        tracks = []
+        async for entry in AsyncIter(entries, steps=25):
+            with contextlib.suppress(Exception):
+                tracks.append(self.decode_track(entry))
+        return web_version, tracks
+
+    async def _build_bundled_playlist(self, forced=False):
+        current_version = await self.config.bundled_playlist_version()
+        web_version, tracks = await self._get_bundled_playlist_tracks()
+
+        if not forced and current_version >= web_version:
+            return
+
+        playlist_data = dict()
+        playlist_data["name"] = "Aikaterna's curated tracks"
+        playlist_data["tracks"] = tracks
+
+        playlist = await PlaylistCompat23.from_json(
+            bot=self.bot,
+            playlist_api=self.playlist_api,
+            scope=PlaylistScope.GLOBAL.value,
+            playlist_number=42069,
+            data=playlist_data,
+            guild=None,
+            author=self.bot.user.id,
+        )
+        await playlist.save()
+        await self.config.bundled_playlist_version.set(web_version)
+        log.info("Curated playlist has been updated.")
